@@ -7,9 +7,9 @@ use crate::operators::{
     binary_operator::BinaryOperator, mask::VectorMask, options::OperatorOptions,
 };
 
-use crate::sparse_vector::SparseVector;
 use crate::util::{ElementIndexSelector, ElementIndexSelectorGraphblasType, IndexConversion};
-use crate::value_type::{AsBoolean, ValueType};
+use crate::value_types::sparse_vector::SparseVector;
+use crate::value_types::value_type::{AsBoolean, ValueType};
 
 use crate::bindings_to_graphblas_implementation::{
     GrB_BinaryOp, GrB_Descriptor, GxB_Vector_subassign_BOOL, GxB_Vector_subassign_FP32,
@@ -20,6 +20,33 @@ use crate::bindings_to_graphblas_implementation::{
 
 // TODO: explicitly define how dupicates are handled
 
+// Implemented methods do not provide mutable access to GraphBLAS operators or options.
+// Code review must consider that no mtable access is provided.
+// https://doc.rust-lang.org/nomicon/send-and-sync.html
+unsafe impl Send for InsertScalarIntoSubVector<bool, bool> {}
+unsafe impl Send for InsertScalarIntoSubVector<u8, u8> {}
+unsafe impl Send for InsertScalarIntoSubVector<u16, u16> {}
+unsafe impl Send for InsertScalarIntoSubVector<u32, u32> {}
+unsafe impl Send for InsertScalarIntoSubVector<u64, u64> {}
+unsafe impl Send for InsertScalarIntoSubVector<i8, i8> {}
+unsafe impl Send for InsertScalarIntoSubVector<i16, i16> {}
+unsafe impl Send for InsertScalarIntoSubVector<i32, i32> {}
+unsafe impl Send for InsertScalarIntoSubVector<i64, i64> {}
+unsafe impl Send for InsertScalarIntoSubVector<f32, f32> {}
+unsafe impl Send for InsertScalarIntoSubVector<f64, f64> {}
+
+unsafe impl Sync for InsertScalarIntoSubVector<bool, bool> {}
+unsafe impl Sync for InsertScalarIntoSubVector<u8, u8> {}
+unsafe impl Sync for InsertScalarIntoSubVector<u16, u16> {}
+unsafe impl Sync for InsertScalarIntoSubVector<u32, u32> {}
+unsafe impl Sync for InsertScalarIntoSubVector<u64, u64> {}
+unsafe impl Sync for InsertScalarIntoSubVector<i8, i8> {}
+unsafe impl Sync for InsertScalarIntoSubVector<i16, i16> {}
+unsafe impl Sync for InsertScalarIntoSubVector<i32, i32> {}
+unsafe impl Sync for InsertScalarIntoSubVector<i64, i64> {}
+unsafe impl Sync for InsertScalarIntoSubVector<f32, f32> {}
+unsafe impl Sync for InsertScalarIntoSubVector<f64, f64> {}
+
 #[derive(Debug, Clone)]
 pub struct InsertScalarIntoSubVector<VectorToInsertInto: ValueType, ScalarToInsert: ValueType> {
     _vector_to_insert_into: PhantomData<VectorToInsertInto>,
@@ -213,8 +240,10 @@ mod tests {
     use crate::context::{Context, Mode};
     use crate::operators::binary_operator::First;
 
-    use crate::sparse_vector::{FromVectorElementList, GetVectorElementValue, VectorElementList};
     use crate::util::ElementIndex;
+    use crate::value_types::sparse_vector::{
+        FromVectorElementList, GetVectorElementValue, VectorElementList,
+    };
 
     #[test]
     fn test_insert_scalar_into_vector() {
